summaryrefslogtreecommitdiff
path: root/src/game/game_instance.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/game_instance.cpp')
-rw-r--r--src/game/game_instance.cpp10
1 files changed, 4 insertions, 6 deletions
diff --git a/src/game/game_instance.cpp b/src/game/game_instance.cpp
index 47374525f..8433567c7 100644
--- a/src/game/game_instance.cpp
+++ b/src/game/game_instance.cpp
@@ -81,16 +81,14 @@ void GameInstance::Died()
/**
* DoCommand callback function for all commands executed by Game Scripts.
- * @param result The result of the command.
* @param cmd cmd as given to DoCommandPInternal.
+ * @param result The result of the command.
* @param tile The tile on which the command was executed.
* @param p1 p1 as given to DoCommandPInternal.
* @param p2 p2 as given to DoCommandPInternal.
* @param text text as given to DoCommandPInternal.
*/
-void CcGame(const CommandCost &result, Commands cmd, TileIndex tile, uint32 p1, uint32 p2, const std::string &text)
+void CcGame(Commands cmd, const CommandCost &result, TileIndex tile, const CommandDataBuffer &data)
{
- if (Game::GetGameInstance()->DoCommandCallback(result, tile, p1, p2, cmd)) {
+ if (Game::GetGameInstance()->DoCommandCallback(result, tile, data, cmd)) {
Game::GetGameInstance()->Continue();
}
}
@@ -81,16 +81,14 @@ void GameInstance::Died()
* @param tile The tile on which the command was executed.
- * @param p1 p1 as given to DoCommandPInternal.
- * @param p2 p2 as given to DoCommandPInternal.
- * @param text text as given to DoCommandPInternal.
+ * @param data Command data as given to Command<>::Post.
*/